@@ -2,7 +2,7 @@
 /**
  * Turba directory driver implementation for an IMSP server.
  *
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -125,7 +125,7 @@ class Turba_Driver_Imsp extends Turba_Driver
             $results = $result;
         }
 
-        Horde::logMessage(sprintf('IMSP returned %s results', count($results)), 'DEBUG');
+        Horde::log(sprintf('IMSP returned %s results', count($results)), 'DEBUG');
 
         return $count_only ? count($results) : array_values($results);
     }
@@ -256,11 +256,12 @@ class Turba_Driver_Imsp extends Turba_Driver
      * Adds the specified contact to the addressbook.
      *
      * @param array $attributes  The attribute values of the contact.
-     * @param array $blob_fields TODO
+     * @param array $blob_fields  Fields that represent binary data.
+     * @param array $date_fields  Fields that represent dates. @since 4.2.0
      *
      * @throws Turba_Exception
      */
-    protected function _add(array $attributes, array $blob_fields = array())
+    protected function _add(array $attributes, array $blob_fields = array(), array $date_fields = array())
     {
         /* We need to map out Turba_Object_Groups back to IMSP groups before
          * writing out to the server. We need to array_values() it in
