@@ -2,7 +2,7 @@
 /**
  * Horde Turba driver for the Kolab IMAP Server.
  *
- * Copyright 2004-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2004-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -38,6 +38,13 @@ class Turba_Driver_Kolab extends Turba_Driver
      */
     protected $_data;
 
+    /**
+     * The current addressbook, serving groups.
+     *
+     * @var Horde_Kolab_Storage_Data
+     */
+    protected $_listData;
+
     /**
      * The current addressbook represented as share.
      *
@@ -62,6 +69,13 @@ class Turba_Driver_Kolab extends Turba_Driver
         'delete_all' => true,
     );
 
+    /**
+     * Any additional options passed to Turba_Object constructors.
+     *
+     * @var array
+     */
+    protected $_objectOptions = array('removeMissing' => true);
+
     /**
      * Attempts to open a Kolab Groupware folder.
      */
@@ -94,23 +108,25 @@ class Turba_Driver_Kolab extends Turba_Driver
      */
     public function toDriverKeys(array $hash)
     {
+        if (isset($hash['__tags'])) {
+            if (!is_array($hash['__tags'])) {
+                $hash['__tags'] = $GLOBALS['injector']
+                    ->getInstance('Turba_Tagger')
+                    ->split($hash['__tags']);
+            }
+            usort($hash['__tags'], 'strcoll');
+            $hash['__internaltags'] = serialize($hash['__tags']);
+        }
+
         $hash = parent::toDriverKeys($hash);
 
         if (isset($hash['name'])) {
             $hash['name'] = array('full-name' => $hash['name']);
         }
 
-        if (isset($hash['emails'])) {
-            $list = new Horde_Mail_Rfc822_List($hash['emails']);
-            $hash['email'] = array();
-            foreach ($list as $address) {
-                $hash['email'][] = array('smtp-address' => $address->bare_address);
-            }
-            unset($hash['emails']);
-        }
-
         /* TODO: use Horde_Kolab_Format_Xml_Type_Composite_* */
-        foreach (array('given-name',
+        foreach (array('full-name',
+                       'given-name',
                        'middle-names',
                        'last-name',
                        'initials',
@@ -122,6 +138,20 @@ class Turba_Driver_Kolab extends Turba_Driver
             }
         }
 
+        if (isset($hash['__type']) && $hash['__type'] == 'Group' &&
+            isset($hash['name']['full-name'])) {
+            $hash['display-name'] = $hash['name']['full-name'];
+        }
+
+        if (isset($hash['emails'])) {
+            $list = new Horde_Mail_Rfc822_List($hash['emails']);
+            $hash['email'] = array();
+            foreach ($list as $address) {
+                $hash['email'][] = array('smtp-address' => $address->bare_address);
+            }
+            unset($hash['emails']);
+        }
+
         foreach (array('phone-business1',
                        'phone-business2',
                        'phone-businessfax',
@@ -180,7 +210,7 @@ class Turba_Driver_Kolab extends Turba_Driver
         }
 
         if (isset($hash['categories'])) {
-            $hash['categories'] = array($hash['categories']);
+            $hash['categories'] = unserialize($hash['categories']);
         }
 
         if (!empty($hash['birthday'])) {
@@ -194,34 +224,84 @@ class Turba_Driver_Kolab extends Turba_Driver
     }
 
     /**
-     * Return the Kolab data handler for the current address book.
+     * Translates a hash from being keyed on driver-specific fields to being
+     * keyed on the generalized Turba attributes. The translation is based on
+     * the contents of $this->map.
+     *
+     * @param array $entry  A hash using driver-specific keys.
+     *
+     * @return array  Translated version of $entry.
+     */
+    public function toTurbaKeys(array $entry)
+    {
+        if (isset($entry['__type']) &&
+            $entry['__type'] == 'Group' &&
+            isset($entry['display-name'])) {
+            $entry['last-name'] = $entry['display-name'];
+        }
+
+        return parent::toTurbaKeys($entry);
+    }
+
+    /**
+     * Returns the Kolab data handler for contacts in the current address book.
      *
      * @return Horde_Kolab_Storage_Data The data handler.
      */
     protected function _getData()
     {
         if ($this->_data === null) {
-            if (!empty($this->_share)) {
-                $share = $this->_share;
-            } else {
-                if (empty($this->_name)) {
-                    throw new Turba_Exception(
-                        'The addressbook has been left undefined but is required!'
-                    );
-                }
-
-                $share = $GLOBALS['injector']
-                    ->getInstance('Turba_Shares')
-                    ->getShare($addressbook);
-            }
-
-            $this->_data = $this->_kolab->getData($share->get('folder'), 'contact');
-            $this->setContactOwner($share->get('owner'));
+            $this->_data = $this->_createData('contact');
         }
 
         return $this->_data;
     }
 
+    /**
+     * Returns the Kolab data handler for distribution lists in the current
+     * address book.
+     *
+     * @return Horde_Kolab_Storage_Data The data handler.
+     */
+    protected function _getListData()
+    {
+        if ($this->_listData === null) {
+            $this->_listData = $this->_createData('distribution-list');
+        }
+
+        return $this->_listData;
+    }
+
+    /**
+     * Returns a new Kolab data handler for the current address book.
+     *
+     * @param string $type  An object type, either 'contact' or
+     *                      'distribution-list'.
+     *
+     * @return Horde_Kolab_Storage_Data  A data handler.
+     */
+    protected function _createData($type)
+    {
+        if (!empty($this->_share)) {
+            $share = $this->_share;
+        } else {
+            if (empty($this->_name)) {
+                throw new Turba_Exception(
+                    'The addressbook has been left undefined but is required!'
+                );
+            }
+
+            $share = $GLOBALS['injector']
+                ->getInstance('Turba_Shares')
+                ->getShare($this->_name);
+        }
+
+        $data = $this->_kolab->getData($share->get('folder'), $type);
+        $this->setContactOwner($share->get('owner'));
+
+        return $data;
+    }
+
     /**
      * Connect to the Kolab backend.
      *
@@ -240,15 +320,31 @@ class Turba_Driver_Kolab extends Turba_Driver
         }
         $contacts = array();
         foreach ($raw_contacts as $id => $contact) {
+            if ($contact->getType() != 'contact') {
+                continue;
+            }
+            $backendId = $contact->getBackendId();
             $contact = $contact->getData();
+            $contact['__type'] = 'Object';
             $contact['__key'] = Horde_Url::uriB64Encode($id);
 
+            if (isset($contact['categories'])) {
+                $contact['categories'] = serialize($contact['categories']);
+            }
+
             if (isset($contact['picture'])) {
                 $name = $contact['picture'];
-                if (isset($contact['_attachments'][$name])) {
-                    $contact['photo'] = $this->_getData()
-                        ->getAttachment($contact['_attachments'][$name]['key']);
-                    $contact['phototype'] = $contact['_attachments'][$name]['type'];
+                $stream = $this->_getData()->getAttachment($backendId, $name);
+                if ($stream) {
+                    $contact['photo'] = new Horde_Stream_Existing(array(
+                        'stream' => $stream
+                    ));
+                    foreach ($contact['_attachments']['type'] as $type => $list) {
+                        if (array_search($name, $list) !== false) {
+                            $contact['phototype'] = $type;
+                            break;
+                        }
+                    }
                 }
             }
 
@@ -290,14 +386,6 @@ class Turba_Driver_Kolab extends Turba_Driver
                 unset($contact['address']);
             }
 
-            if (isset($contact['categories'])) {
-                if (empty($contact['categories'])) {
-                    $contact['categories'] = '';
-                } else {
-                    $contact['categories'] = $contact['categories'][0];
-                }
-            }
-
             if (!empty($contact['birthday'])) {
                 $contact['birthday'] = $contact['birthday']->format('Y-m-d');
             }
@@ -309,13 +397,22 @@ class Turba_Driver_Kolab extends Turba_Driver
         }
 
         /* Now we retrieve distribution-lists */
+        $raw_groups = $this->_getListData()->getObjects();
         $groups = array();
-        //@todo: group support
-        /* $result = $this->_store->setObjectType('distribution-list'); */
-        /* $groups = $this->_store->getObjects(); */
-        /* if (!$groups) { */
-        /*     $groups = array(); */
-        /* } */
+        if ($raw_groups) {
+            foreach ($raw_groups as $id => $group) {
+                if ($group->getType() != 'distribution-list') {
+                    continue;
+                }
+                $group = $group->getData();
+                $group['__type'] = 'Group';
+                $group['__key'] = Horde_Url::uriB64Encode($id);
+                if (isset($group['categories'])) {
+                    $group['categories'] = serialize($group['categories']);
+                }
+                $groups[Horde_Url::uriB64Encode($id)] = $group;
+            }
+        }
 
         /* Store the results in our cache */
         $this->_contacts_cache = array_merge($contacts, $groups);
@@ -354,15 +451,18 @@ class Turba_Driver_Kolab extends Turba_Driver
         $ids = $this->_removeDuplicated($ids);
 
         /* Now we have a list of names, get the rest. */
-        $result = $this->_read(
-            'uid',
-            array_map(array('Horde_Url', 'uriB64Encode'), $ids),
-            null,
-            $fields
-        );
+        if ($ids) {
+            $result = $this->_read(
+                'uid',
+                array_map(array('Horde_Url', 'uriB64Encode'), $ids),
+                null,
+                $fields
+            );
+        } else {
+            $result = array();
+        }
 
-        Horde::logMessage(sprintf('Kolab returned %s results',
-                                  count($result)), 'DEBUG');
+        Horde::log(sprintf('Kolab returned %s results', count($result)), 'DEBUG');
 
         return $count_only ? count($result) : array_values($result);
     }
@@ -424,7 +524,7 @@ class Turba_Driver_Kolab extends Turba_Driver
         $ids = array();
 
         if (!isset($test['field'])) {
-            Horde::logMessage('Search field not set. Returning all entries.', 'DEBUG');
+            Horde::log('Search field not set. Returning all entries.', 'DEBUG');
             foreach ($this->_contacts_cache as $entry) {
                 $ids[] = $entry['uid'];
             }
@@ -523,12 +623,15 @@ class Turba_Driver_Kolab extends Turba_Driver
      * @param string $owner      Only return contacts owned by this user.
      * @param array $fields      List of fields to return.
      * @param array $blobFields  Array of fields containing binary data.
+     * @param array $dateFields  Array of fields containing date data.
+     *                           @since 4.2.0
      *
      * @return array  Hash containing the search results.
      * @throws Turba_Exception
      */
     protected function _read($key, $ids, $owner, array $fields,
-                             array $blobFields = array())
+                             array $blobFields = array(),
+                             array $dateFields = array())
     {
         $this->connect();
 
@@ -540,61 +643,89 @@ class Turba_Driver_Kolab extends Turba_Driver
 
         $count = count($fields);
         foreach ($ids as $id) {
-            if (isset($this->_contacts_cache[$id])) {
-                $object = $this->_contacts_cache[$id];
-
-                if (!isset($object['__type']) || $object['__type'] == 'Object') {
-                    if ($count) {
-                        $result = array();
-                        foreach ($fields as $field) {
-                            if (isset($object[$field])) {
-                                $result[$field] = $object[$field];
-                            }
-                        }
-                        $results[] = $result;
-                    } else {
-                        $results[] = $object;
-                    }
-                } else {
-                    $member_ids = array();
-                    if (isset($object['member'])) {
-                        foreach ($object['member'] as $member) {
-                            if (isset($member['uid'])) {
-                                $member_ids[] = $member['uid'];
-                                continue;
-                            }
-                            $display_name = $member['display-name'];
-                            $smtp_address = $member['smtp-address'];
-                            $criteria = array(
-                                'AND' => array(
-                                    array(
-                                        'field' => 'full-name',
-                                        'op' => 'LIKE',
-                                        'test' => $display_name,
-                                        'begin' => false,
-                                    ),
-                                    array(
-                                        'field' => 'emails',
-                                        'op' => 'LIKE',
-                                        'test' => $smtp_address,
-                                        'begin' => false,
-                                    ),
-                                ),
-                            );
-                            $fields = array('uid');
-
-                            // we expect only one result here!!!
-                            $contacts = $this->_search($criteria, $fields);
-
-                            // and drop everything else except the first search result
-                            $member_ids[] = $contacts[0]['uid'];
-                        }
-                        $object['__members'] = serialize($member_ids);
-                        unset($object['member']);
-                    }
-                    $results[] = $object;;
-                }
+            if (!isset($this->_contacts_cache[$id])) {
+                continue;
             }
+            $object = $this->_contacts_cache[$id];
+
+            if (!isset($object['__type']) || $object['__type'] == 'Object') {
+                if ($count) {
+                    $result = array();
+                    foreach ($fields as $field) {
+                        if (isset($object[$field])) {
+                            $result[$field] = $object[$field];
+                        }
+                    }
+                    $results[] = $result;
+                } else {
+                    $results[] = $object;
+                }
+            } else {
+                $member_ids = array();
+                if (isset($object['member'])) {
+                    foreach ($object['member'] as $member) {
+                        if (isset($member['uid'])) {
+                            $id = Horde_Url::uriB64Encode($member['uid']);
+                            $found = false;
+                            try {
+                                $this->getObject($id);
+                                $found = true;
+                            } catch (Horde_Exception_NotFound $e) {
+                                foreach (Turba::listShares() as $share) {
+                                    $driver = $GLOBALS['injector']
+                                        ->getInstance('Turba_Factory_Driver')
+                                        ->create($share->getName());
+                                    try {
+                                        $driver->getObject($id);
+                                        $id = $share->getName() . ':' . $id;
+                                        $found = true;
+                                        break;
+                                    } catch (Horde_Exception_NotFound $e) {
+                                        continue;
+                                    }
+                                }
+                            }
+                            if ($found) {
+                                $member_ids[] = $id;
+                            }
+                            continue;
+                        }
+                        $display_name = $member['display-name'];
+                        $smtp_address = $member['smtp-address'];
+                        $criteria = array(
+                            'AND' => array(
+                                array(
+                                    'field' => 'full-name',
+                                    'op' => 'LIKE',
+                                    'test' => $display_name,
+                                    'begin' => false,
+                                ),
+                                array(
+                                    'field' => 'emails',
+                                    'op' => 'LIKE',
+                                    'test' => $smtp_address,
+                                    'begin' => false,
+                                ),
+                            ),
+                        );
+                        $fields = array('uid');
+
+                        // we expect only one result here!!!
+                        $contacts = $this->_search($criteria, $fields);
+
+                        // and drop everything else except the first search
+                        // result
+                        $member_ids[] = $contacts[0]['__key'];
+                    }
+                    $object['__members'] = serialize($member_ids);
+                    unset($object['member']);
+                }
+                $results[] = $object;
+            }
+        }
+
+        if (!$results) {
+            throw new Horde_Exception_NotFound();
         }
 
         return $results;
@@ -604,11 +735,12 @@ class Turba_Driver_Kolab extends Turba_Driver
      * Adds the specified contact to the addressbook.
      *
      * @param array $attributes  The attribute values of the contact.
-     * @param array $blob_fields TODO
+     * @param array $blob_fields  Fields that represent binary data.
+     * @param array $date_fields  Fields that represent dates. @since 4.2.0
      *
      * @throws Turba_Exception
      */
-    protected function _add(array $attributes, array $blob_fields = array())
+    protected function _add(array $attributes, array $blob_fields = array(), array $date_fields = array())
     {
         $this->connect();
         $this->_store($attributes);
@@ -633,18 +765,15 @@ class Turba_Driver_Kolab extends Turba_Driver
         }
 
         if (!isset($this->_contacts_cache[$object_id])) {
-            throw new Turba_Exception(sprintf(_("Object with UID %s does not exist!"), $uid));
+            throw new Turba_Exception(sprintf(_("Object with UID %s does not exist!"), $object_id));
         }
 
-        $group = isset($this->_contacts_cache[$object_id]['__type']) &&
-            $this->_contacts_cache[$object_id]['__type'] == 'Group';
+        $data = isset($this->_contacts_cache[$object_id]['__type']) &&
+            $this->_contacts_cache[$object_id]['__type'] == 'Group'
+            ? $this->_getListData()
+            : $this->_getData();
 
-        if ($group) {
-            //@todo: group support
-            //$result = $this->_store->setObjectType('distribution-list');
-        }
-
-        $result = $this->_getData()->delete($this->_contacts_cache[$object_id]['uid']);
+        $result = $data->delete($this->_contacts_cache[$object_id]['uid']);
 
         /* Invalidate cache. */
         $this->_connected = false;
@@ -667,11 +796,7 @@ class Turba_Driver_Kolab extends Turba_Driver
 
         /* Delete contacts */
         $this->_getData()->deleteAll();
-
-        /* Delete groups */
-        //@todo: group support
-        //$result = $this->_store->setObjectType('distribution-list');
-        //$result = $this->_store->deleteAll();
+        $this->_getListData()->deleteAll();
 
         return $uids;
     }
@@ -701,40 +826,36 @@ class Turba_Driver_Kolab extends Turba_Driver
      */
     protected function _store($attributes, $object_id = null)
     {
-        $group = false;
         if (isset($attributes['__type']) && $attributes['__type'] == 'Group') {
-            return;
-            //@todo: group support
-            /* $group = true; */
-            /* $result = $this->_store->setObjectType('distribution-list'); */
-            /* $this->_convertMembers($attributes); */
-        }
-
-        if (isset($attributes['photo']) && isset($attributes['phototype'])) {
-            $attributes['_attachments']['photo.attachment'] = array(
-                'type' => $attributes['phototype'],
-                'content' => $attributes['photo']
-            );
-            $attributes['picture'] = 'photo.attachment';
-            unset($attributes['photo'], $attributes['phototype']);
-        }
-
-        // EAS sets the date fields to '' instead of null -> fix it up
-        $fix_date_fields = array('birthday', 'anniversary');
-        foreach($fix_date_fields as $fix_date) {
-            if (empty($attributes[$fix_date])) {
-                unset($attributes[$fix_date]);
+            $this->_convertMembers($attributes);
+            $data = $this->_getListData();
+        } else {
+            if (isset($attributes['photo']) && isset($attributes['phototype'])) {
+                $filename = 'photo.'
+                    . Horde_Mime_Magic::mimeToExt($attributes['phototype']);
+                $attributes['_attachments'][$filename] = array(
+                    'type' => $attributes['phototype'],
+                    'content' => Horde_Stream_Wrapper_String::getStream($attributes['photo'])
+                );
+                $attributes['picture'] = $filename;
+                unset($attributes['photo'], $attributes['phototype']);
             }
+
+            // EAS sets the date fields to '' instead of null -> fix it up
+            $fix_date_fields = array('birthday', 'anniversary');
+            foreach ($fix_date_fields as $fix_date) {
+                if (empty($attributes[$fix_date])) {
+                    unset($attributes[$fix_date]);
+                }
+            }
+            $data = $this->_getData();
         }
 
         if ($object_id === null) {
-            $object_id = $this->_getData()->create($attributes);
+            $object_id = $data->create($attributes);
         } else {
-            $object_id = $this->_getData()->modify($attributes);
+            $data->modify($attributes);
         }
-        /* if ($group) {
-            $result = $this->_store->setObjectType('contact');
-        } */
 
         /* Invalidate cache. */
         $this->_connected = false;
@@ -750,11 +871,36 @@ class Turba_Driver_Kolab extends Turba_Driver
         if (isset($attributes['__members'])) {
             $member_ids = unserialize($attributes['__members']);
             $attributes['member'] = array();
-            foreach ($member_ids as $uid) {
-                $member_id = Horde_Url::uriB64Encode($uid);
-                if (isset($this->_contacts_cache[$member_id])) {
+            foreach ($member_ids as $member_id) {
+                $source_id = null;
+                if (strpos($member_id, ':')) {
+                    list($source_id, $member_id) = explode(':', $member_id, 2);
+                }
+                $mail = array('uid' => Horde_Url::uriB64Decode($member_id));
+                $member = null;
+                if ($source_id) {
+                    try {
+                        $driver = $GLOBALS['injector']->getInstance('Turba_Factory_Driver')->create($source_id);
+                        try {
+                            $member = $driver->getObject($member_id);
+                            $name = $member->getValue('name');
+                            if (!empty($name)) {
+                                $mail['display-name'] = $name;
+                            }
+                            $emails = $member->getValue('emails');
+                            if ($emails) {
+                                $emails = explode(',', $emails);
+                                $mail['smtp-address'] = trim($emails[0]);
+                                if (!isset($mail['display-name'])) {
+                                    $mail['display-name'] = $mail['smtp-address'];
+                                }
+                            }
+                        } catch (Horde_Exception_NotFound $e) {
+                        }
+                    } catch (Turba_Exception $e) {
+                    }
+                } elseif (isset($this->_contacts_cache[$member_id])) {
                     $member = $this->_contacts_cache[$member_id];
-                    $mail = array('uid' => $uid);
                     if (!empty($member['full-name'])) {
                         $mail['display-name'] = $member['full-name'];
                     }
@@ -765,8 +911,8 @@ class Turba_Driver_Kolab extends Turba_Driver
                             $mail['display-name'] = $mail['smtp-address'];
                         }
                     }
-                    $attributes['member'][] = $mail;
                 }
+                $attributes['member'][] = $mail;
             }
             unset($attributes['__members']);
         }
