@@ -14,7 +14,7 @@
 /**
  * A Horde_Injector:: based Turba_Driver:: factory.
  *
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (APL). If you
  * did not receive this file, see http://www.horde.org/licenses/apl.html.
@@ -79,7 +79,7 @@ class Turba_Factory_Driver extends Horde_Core_Factory_Base
                         ? $srcConfig['params']['sql']['charset']
                         : 'UTF-8';
                 } catch (Horde_Db_Exception $e) {
-                    throw new Turba_Exception($e);
+                    throw new Turba_Exception(_("Server error when initializing database connection."));
                 }
                 break;
 
