@@ -1,17 +1,25 @@
 <?php
 /**
- * Turba Base Class.
- *
- * Copyright 2000-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2000-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
- * @author   Chuck Hagenbuch <chuck@horde.org>
- * @author   Jon Parise <jon@horde.org>
- * @category Horde
- * @license  http://www.horde.org/licenses/apache ASL
- * @package  Turba
+ * @category  Horde
+ * @copyright 2000-2014 Horde LLC
+ * @license   http://www.horde.org/licenses/apache ASL
+ * @package   Turba
+ */
+
+/**
+ * Turba Base Class.
+ *
+ * @author    Chuck Hagenbuch <chuck@horde.org>
+ * @author    Jon Parise <jon@horde.org>
+ * @category  Horde
+ * @copyright 2000-2014 Horde LLC
+ * @license   http://www.horde.org/licenses/apache ASL
+ * @package   Turba
  */
 class Turba
 {
@@ -39,16 +47,21 @@ class Turba
      * configured as available sources in the main Turba configuration.
      *
      * @return array  List of available sources.
+     * @throws Horde_Exception
      */
     static public function availableSources()
     {
-        $cfgSources = Horde::loadConfiguration('backends.php', 'cfgSources', 'turba');
+        global $registry;
+
+        $s = $registry->loadConfigFile('backends.php', 'cfgSources', 'turba')->config['cfgSources'];
+
         $sources = array();
-        foreach ($cfgSources as $key => $source) {
+        foreach ($s as $key => $source) {
             if (empty($source['disabled'])) {
                 $sources[$key] = $source;
             }
         }
+
         return $sources;
     }
 
@@ -177,7 +190,8 @@ class Turba
                     $source = array_splice($cols, 0, 1);
                     $columns[$source[0]] = array();
                     foreach ($cols as $col) {
-                        if (isset($GLOBALS['cfgSources'][$source[0]]['map'][$col])) {
+                        if ($col == '__tags' ||
+                            isset($GLOBALS['cfgSources'][$source[0]]['map'][$col])) {
                             $columns[$source[0]][] = $col;
                         }
                     }
@@ -397,13 +411,14 @@ class Turba
     }
 
     /**
-     * Filters data based on permissions.
+     * Filters sources based on permissions.
      *
-     * @param array $in            The data we want filtered.
-     * @param string $filter       What type of data we are filtering.
+     * @param array $in            The source list we want filtered.
      * @param integer $permission  The Horde_Perms::* constant we will filter
      *                             on.
-     * @param array $options       Additional options.
+     * @param array $options       Additional options:
+     *                             - require_add: (boolean) Only return sources
+     *                               that can be added to.
      *
      * @return array  The filtered data.
      */
@@ -416,13 +431,13 @@ class Turba
 
         foreach ($in as $sourceId => $source) {
             try {
-                $driver = $factory->create($sourceId);
+                $driver = $factory->create($source);
                 if ($driver->hasPermission($permission) &&
                     (empty($options['require_add']) || $driver->canAdd())) {
                     $out[$sourceId] = $source;
                 }
             } catch (Turba_Exception $e) {
-                Horde::logMessage($e, 'ERR');
+                Horde::log($e, 'ERR');
             }
         }
 
@@ -433,18 +448,20 @@ class Turba
      * Replaces all share-enabled sources in a source list with all shares
      * from this source that the current user has access to.
      *
-     * This will only sync shares that are unique to Horde (such as a SQL
-     * source).  Any backend that supports ACLs or similar mechanism should be
-     * configured from within backends.php or via Horde's share_* hooks.
+     * This will only sync shares that are unique to Horde (such as a SQL or
+     * Kolab sources).  Any backend that supports ACLs or similar mechanism
+     * should be configured from within backends.local.php or via Horde's
+     * share_* hooks.
      *
      * @param array $sources  The default $cfgSources array.
+     * @param boolean $owner  Only return shares that the current user owns?
      *
      * @return array  The $cfgSources array.
      */
-    static public function getConfigFromShares(array $sources)
+    static public function getConfigFromShares(array $sources, $owner = false)
     {
         try {
-            $shares = self::listShares();
+            $shares = self::listShares($owner);
         } catch (Horde_Share_Exception $e) {
             // Notify the user if we failed, but still return the $cfgSource
             // array.
@@ -490,7 +507,7 @@ class Turba
                     try {
                         $share->save();
                     } catch (Horde_Share_Exception $e) {
-                        Horde::logMessage($e, 'ERR');
+                        Horde::log($e, 'ERR');
                     }
                 }
 
@@ -552,7 +569,7 @@ class Turba
                     $personal = true;
                     $GLOBALS['prefs']->setValue('default_dir', $share->getName());
                 } catch (Horde_Share_Exception $e) {
-                    Horde::logMessage($e, 'ERR');
+                    Horde::log($e, 'ERR');
                 }
             }
         }
@@ -627,7 +644,7 @@ class Turba
                 )
             );
         } catch (Horde_Share_Exception $e) {
-            Horde::logMessage($e, 'ERR');
+            Horde::log($e, 'ERR');
             return array();
         }
     }
@@ -667,7 +684,7 @@ class Turba
             $turba_shares->addShare($share);
             $share->save();
         } catch (Horde_Share_Exception $e) {
-            Horde::logMessage($e, 'ERR');
+            Horde::log($e, 'ERR');
             throw new Turba_Exception($e);
         }
 
