@@ -3,7 +3,7 @@
  * The Turba_View_Browse class provides the logic for browsing lists
  * of contacts.
  *
- * Copyright 2000-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2000-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -44,9 +44,7 @@ class Turba_View_Browse
             $notification->push(_("There are no browseable address books."), 'horde.warning');
         } else {
             try {
-                $driver = $GLOBALS['injector']
-                    ->getInstance('Turba_Factory_Driver')
-                    ->create($source);
+                $driver = $factory->create($source);
             } catch (Turba_Exception $e) {
                 $notification->push($e, 'horde.error');
                 unset($driver);
@@ -136,9 +134,7 @@ class Turba_View_Browse
                 $targetSource = $vars->get('targetAddressbook');
 
                 try {
-                    $targetDriver = $GLOBALS['injector']
-                        ->getInstance('Turba_Factory_Driver')
-                        ->create($targetSource);
+                    $targetDriver = $factory->create($targetSource);
                 } catch (Turba_Exception $e) {
                     $notification->push($e, 'horde.error');
                     break;
@@ -167,9 +163,7 @@ class Turba_View_Browse
 
                     // Try and load the driver for the source.
                     try {
-                        $sourceDriver = $GLOBALS['injector']
-                            ->getInstance('Turba_Factory_Driver')
-                            ->create($objectSource);
+                        $sourceDriver = $factory->create($objectSource);
                     } catch (Turba_Exception $e) {
                         $notification->push($e, 'horde.error');
                         continue;
@@ -204,7 +198,7 @@ class Turba_View_Browse
                     $objAttributes = array();
 
                     // Get the values through the Turba_Object class.
-                    foreach ($targetDriver->getCriteria() as $info_key => $info_val) {
+                    foreach (array_keys($targetDriver->getCriteria()) as $info_key) {
                         if (!is_array($targetDriver->map[$info_key]) ||
                             isset($targetDriver->map[$info_key]['attribute'])) {
                             $objectValue = $object->getValue($info_key);
@@ -212,9 +206,10 @@ class Turba_View_Browse
                             // Get 'data' value if object type is image, the
                             // direct value in other case.
                             $objAttributes[$info_key] =
-                                isset($GLOBALS['attributes'][$info_key]) &&
-                                      $GLOBALS['attributes'][$info_key]['type'] == 'image' ?
-                                        $objectValue['load']['data'] : $objectValue;
+                                isset($attributes[$info_key]) &&
+                                    $attributes[$info_key]['type'] == 'image'
+                                    ? $objectValue['load']['data']
+                                    : $objectValue;
                         }
                     }
                     unset($objAttributes['__owner']);
@@ -256,12 +251,11 @@ class Turba_View_Browse
                          * because otherwise the delete log would be after the
                          * add log. */
                         try {
-                            $GLOBALS['injector']->getInstance('Horde_History')
-                                ->log('turba:' . $targetDriver->getName() . ':' . $objAttributes['__uid'],
+                            $history->log('turba:' . $targetDriver->getName() . ':' . $objAttributes['__uid'],
                                       array('action' => 'add'),
                                       true);
                         } catch (Exception $e) {
-                            Horde::logMessage($e, 'ERR');
+                            Horde::log($e, 'ERR');
                         }
                     }
                 }
@@ -282,9 +276,7 @@ class Turba_View_Browse
                     }
 
                     try {
-                        $targetDriver = $GLOBALS['injector']
-                            ->getInstance('Turba_Factory_Driver')
-                            ->create($targetSource);
+                        $targetDriver = $factory->create($targetSource);
                     } catch (Turba_Exception $e) {
                         $notification->push($e, 'horde.error');
                         break;
@@ -299,9 +291,7 @@ class Turba_View_Browse
                 } else {
                     $targetSource = $vars->get('targetAddressbook');
                     try {
-                        $targetDriver = $GLOBALS['injector']
-                            ->getInstance('Turba_Factory_Driver')
-                            ->create($targetSource);
+                        $targetDriver = $factory->create($targetSource);
                     } catch (Turba_Exception $e) {
                         $notification->push($e, 'horde.error');
                         break;
@@ -416,7 +406,7 @@ class Turba_View_Browse
             // We might get here from the search page but are not allowed to browse
             // the current address book.
             if ($actionID && empty($cfgSources[$source]['browse'])) {
-                Horde::url($GLOBALS['prefs']->getValue('initial_page'), true)
+                Horde::url($prefs->getValue('initial_page'), true)
                     ->redirect();
             }
         }
@@ -480,7 +470,7 @@ class Turba_View_Browse
                     }
 
                     try {
-                        $results = $driver->search($type_filter, $sortorder, 'AND', $columns ? $columns : array('name'));
+                        $results = $driver->search($type_filter, $sortorder, 'AND', array_merge(array('__uid'), $columns ? $columns : array('name')));
                         $view = new Turba_View_List($results, null, $columns);
                         $view->setType('directory');
                     } catch (Turba_Exception $e) {
@@ -492,7 +482,6 @@ class Turba_View_Browse
             $templates[] = '/browse/header.inc';
         }
 
-        global $page_output;
         $page_output->addScriptFile('quickfinder.js', 'horde');
         $page_output->addScriptFile('scriptaculous/effects.js', 'horde');
         $page_output->addScriptFile('redbox.js', 'horde');
