@@ -2,7 +2,7 @@
 /**
  * Turba view.php.
  *
- * Copyright 2004-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2004-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -32,15 +32,9 @@ if (!$object->hasPermission(Horde_Perms::READ)) {
 }
 
 try {
-    $vfs = $object->vfsInit();
-} catch (Horde_Exception $e) {
-    throw new Turba_Exception($e);
-}
-
-try {
-    $data = $vfs->read(Turba::VFS_PATH . '/' . $object->getValue('__uid'), $filename);
+    $data = $object->vfsInit()->read(Turba::VFS_PATH . '/' . $object->getValue('__uid'), $filename);
 } catch (Horde_Vfs_Exception $e) {
-    Horde::logMessage($e, 'ERR');
+    Horde::log($e, 'ERR');
     throw new Turba_Exception(sprintf(_("Access denied to %s"), $filename));
 }
 
